@@ -12,7 +12,7 @@ Python libraries, though it does make heavy use of external packaging commands.
 Visit <https://github.com/datalad/datalad-installer> for more information.
 """
 
-__version__ = "0.9.1"
+__version__ = "0.9.2"
 __author__ = "The DataLad Team and Contributors"
 __author_email__ = "team@datalad.org"
 __license__ = "MIT"
@@ -53,6 +53,7 @@ from typing import (
     Union,
     cast,
 )
+from urllib.error import HTTPError, URLError
 from urllib.request import Request, urlopen
 from zipfile import ZipFile
 
@@ -656,7 +657,7 @@ class DataladInstaller:
         try:
             runcmd(*args, **kwargs)
         except OSError as e:
-            if e.winerror == 740:  # type: ignore[attr-defined]
+            if getattr(e, "winerror", None) == 740:
                 log.info("Operation requires elevation; rerunning as administrator")
                 self.sudo(*args, **kwargs)
             else:
@@ -666,7 +667,12 @@ class DataladInstaller:
         # `dest` must be a file path, not a directory path.
         log.info("Moving %s to %s", path, dest)
         try:
-            path.replace(dest)
+            if ON_POSIX:
+                # Handle cross-filesystem moves  (Don't use shutil.move() on
+                # Windows, as it fails when dest exists)
+                shutil.move(str(path), str(dest))
+            else:
+                path.replace(dest)
         except PermissionError:
             log.info("Operation requires elevation; rerunning as administrator")
             if ON_POSIX:
@@ -997,7 +1003,11 @@ class MinicondaComponent(Component):
         if ON_LINUX:
             miniconda_script = "Miniconda3-latest-Linux-x86_64.sh"
         elif ON_MACOS:
-            miniconda_script = "Miniconda3-latest-MacOSX-x86_64.sh"
+            arch = platform.machine().lower()
+            if arch in ("x86_64", "arm64"):
+                miniconda_script = f"Miniconda3-latest-MacOSX-{arch}.sh"
+            else:
+                raise RuntimeError(f"E: Unsupported architecture: {arch}")
         elif ON_WINDOWS:
             miniconda_script = "Miniconda3-latest-Windows-x86_64.exe"
         else:
@@ -2436,10 +2446,24 @@ def download_file(
     log.info("Downloading %s", url)
     if headers is None:
         headers = {}
+    delays = iter([1, 2, 6, 15, 36])
     req = Request(url, headers=headers)
-    with urlopen(req) as r:
-        with open(path, "wb") as fp:
-            shutil.copyfileobj(r, fp)
+    while True:
+        try:
+            with urlopen(req) as r:
+                with open(path, "wb") as fp:
+                    shutil.copyfileobj(r, fp)
+            return
+        except URLError as e:
+            if isinstance(e, HTTPError) and e.code not in (500, 502, 503, 504):
+                raise
+            try:
+                delay = next(delays)
+            except StopIteration:
+                raise
+            else:
+                log.warning("Request to %s failed: %s", url, e)
+                log.info("Retrying in %d seconds", delay)
 
 
 def download_to_tempfile(
